@@ -1,10 +1,11 @@
 # flake8: noqa
 from dfa.dfa import DFA, State, Letter, Alphabet
-from dfa.utils import dfa2dict, dict2dfa
+from dfa.utils import DFADict, dfa2dict, dict2dfa
 
 __all__ = [
     'Alphabet',
     'DFA',
+    'DFADict',
     'Letter',
     'State',
     'dfa2dict',
